package com.qiaoba.module.system.service;

import com.qiaoba.api.system.entity.SysDictData;
import com.qiaoba.api.system.entity.param.SysDictDataParam;
import com.qiaoba.api.system.service.SysDictApiService;
import com.qiaoba.common.database.entity.PageQuery;
import com.qiaoba.common.database.entity.TableDataInfo;

import java.util.List;

/**
 * 字典类型数据管理 服务层
 *
 * @author ailanyin
 * @version 1.0
 * @since 2022-09-22 04:20:28
 */
public interface SysDictDataService extends SysDictApiService {

    /**
     * 根据字典类型和字典键值查询字典数据信息
     *
     * @param dictType  字典类型
     * @param dictValue 字典键值
     * @return 字典标签
     */
    String selectDictLabel(String dictType, String dictValue);

    /**
     * 根据字典数据ID查询信息
     *
     * @param dictCode 字典数据ID
     * @return 字典数据
     */
    SysDictData selectById(String dictCode);

    /**
     * 批量删除字典数据信息
     *
     * @param ids 需要删除的字典数据ID
     * @return 结果
     */
    int deleteByIds(List<String> ids);

    /**
     * 新增保存字典数据信息
     *
     * @param sysDictData 字典数据信息
     * @return 结果
     */
    int insert(SysDictData sysDictData);

    /**
     * 修改保存字典数据信息
     *
     * @param sysDictData 字典数据信息
     * @return 结果
     */
    int update(SysDictData sysDictData);

    /**
     * 根据条件分页查询字典数据
     *
     * @param param     参数
     * @param pageQuery 分页信息
     * @return 字典数据集合信息
     */
    TableDataInfo selectPageList(SysDictDataParam param, PageQuery pageQuery);

    /**
     * 查询列表
     *
     * @param param param
     * @return list
     */
    List<SysDictData> selectList(SysDictDataParam param);

    /**
     * 根据字典类型查询字典数据
     *
     * @param dictType 字典类型
     * @return 字典数据集合信息
     */
    List<SysDictData> selectByDictType(String dictType);

    /**
     * 重置字典缓存数据
     */
    void resetDictCache();
}
